@@ -7,7 +7,8 @@ errorsarlm <- function(formula, data = list(), listw, na.action, etype="error",
         timings <- list()
         .ptime_start <- proc.time()
         con <- list(tol.opt=.Machine$double.eps^0.5, returnHcov=TRUE,
-            pWOrder=250, fdHess=NULL, optimHess=FALSE, LAPACK=FALSE,
+            pWOrder=250, fdHess=NULL, optimHess=FALSE,
+            optimHessMethod="optimHess", LAPACK=FALSE,
             compiled_sse=FALSE, Imult=2, cheb_q=5, MC_p=16, MC_m=30,
             super=NULL, spamPivot="MMD", in_coef=0.1, type="MC",
             correct=TRUE, trunc=TRUE, SE_method="LU", nrho=200,
@@ -270,7 +271,7 @@ errorsarlm <- function(formula, data = list(), listw, na.action, etype="error",
                 assign("ptr", ptr, envir=env)
             }
             fdHess <- getVmate(coefs, env, s2, trs, tol.solve=tol.solve,
-                optim=con$optimHess)
+                optim=con$optimHess, optimM=con$optimHessMethod)
             if (con$compiled_sse) {
                 .Call("hess_error_free", get("ptr", envir=env),
                     PACKAGE="spdep")
