@@ -53,7 +53,7 @@ dnearneigh(SEXP din1, SEXP din2, SEXP pnte, SEXP p, SEXP test, SEXP lonlat)
 	    } */
 	    lon2[0] = NUMERIC_POINTER(test)[j];
 	    lat2[0] = NUMERIC_POINTER(test)[j + nte];
-	    if (ll == 0) dist = pythag((lon1[0]-lon2[0]), (lat1[0]-lat2[0]));
+	    if (ll == 0) dist = hypot((lon1[0]-lon2[0]), (lat1[0]-lat2[0]));
 	    else {
 		    gcdist(lon1, lon2, lat1, lat2, gc);
 		    dist = gc[0];
